Module ui

Module ui 

Modules

agent_update
camera_position
UI message for changing the position of the player’s camera;
chat_from_simulator
chat_from_viewer
UI message for sending a chat from the viewer to the client
coarse_location_update
disable_simulator
errors
Errors created from messages and the session that should be from the core to the UI.
land_update
UI message for rendering land
login_error
login_event
UI message for requesting a login
login_response
UI message for sending the UI relevant login response data
logout
UI message for requesting a logout
mesh_update
Used for informing the UI that the core has received a layer that should be rendered. Contains the path to the generated gltf file, and the position to render it. This allows all terrain generation to be handled by the client, allowing for very small packets to be sent between the UI and the client.
play_animation
UI message for informing the UI of an animation
skybox_update
UI message for updating the skybox
ui_messages
Structs for defining UI send and receive message types
water_update
UI message for rendering water