MailboxSessionError

Struct MailboxSessionError 

pub struct MailboxSessionError {
    pub message: String,
}
This represents errors that can arise from the mailbox failing to connect. The mailbox is part of the client that handles packet IO and other logic to pass to the UI.

Fields

message: String

String message that contains error information