pub struct InventoryData {
pub inventory_root: Uuid,
pub inventory_lib_owner: Uuid,
pub inventory_init: bool,
}Expand description
Contains information about the Inventory
Fields
inventory_root: UuidThe root of the inventory, received from the LoginResponse. This is a vector of the base UUIDs that will be used to create the root of the inventory tree using a FetchInventoryDescendents2 call.
inventory_lib_owner: UuidThe UUID of the owner of the inventory lib. Used to create the FetchLibDescendents2 call.
inventory_init: boolboolean to signify the inventory has successfully loaded and is ready for use.