Session

Struct Session 

pub struct Session<Capability, Avatar, Land, UdpSocket> {
Show 13 fields pub address: String, pub agent_id: Uuid, pub session_id: Uuid, pub socket: Option<Arc<UdpSocket>>, pub sequence_number: u16, pub local_ip: IpAddr, pub seed_capability_url: String, pub capability_urls: HashMap<Capability, String>, pub inventory_data: InventoryData, pub environment_cache: EnvironmentCache<Land>, pub avatars: HashMap<Uuid, Avatar>, pub region_data: RegionData, pub inventory_db_connection: Pool<Sqlite>,
}
Message and struct for the current user’s session.

This includes all data that will be used throughout the session, and much of it is populated by the LoginResponse packet. This sets the active session for the Mailbox, and ensures the UDP socket doesn’t close.

Cause

  • A login is triggered by the UI, and the handle_login function is called

Effects

  • Starts UDP read between client and server

Fields

address: String

address of the server the client is connected to. formatted http://Url:Socket

agent_id: Uuid

agent ID of the user

session_id: Uuid

session ID of the user

socket: Option<Arc<UdpSocket>>

the running UDP socket attached to the session

sequence_number: u16

The sequence number of the packets sent. Created as a simple count from the core to the server.

local_ip: IpAddr

The local IP that the login is sent from. This is stored to ensure the IP of the UseCircuitCode packet is sent from the same IP as the login, to prevent server errors.

seed_capability_url: String

The URL endpoint to request more capabilities

capability_urls: HashMap<Capability, String>

The HashMap for storing capability URLs

inventory_data: InventoryData

inventory details retrieved from initial login

environment_cache: EnvironmentCache<Land>

The environment cache. Contains things for handling and generating the environment.

avatars: HashMap<Uuid, Avatar>

The agent list. Contains information about the appearances of all loaded agents

region_data: RegionData

data about the region the user is currently in

inventory_db_connection: Pool<Sqlite>

the connection to the inventory sqlite DB this stores folder data and inventory metadata