Modules
- agent_
update - camera_
position - UI message for changing the position of the player’s camera;
- chat_
from_ simulator - chat_
from_ viewer - UI message for sending a chat from the viewer to the client
- coarse_
location_ update - disable_
simulator - errors
- Errors created from messages and the session that should be from the core to the UI.
- land_
update - UI message for rendering land
- login_
error - login_
event - UI message for requesting a login
- login_
response - UI message for sending the UI relevant login response data
- logout
- UI message for requesting a logout
- mesh_
update - Used for informing the UI that the core has received a layer that should be rendered. Contains the path to the generated gltf file, and the position to render it. This allows all terrain generation to be handled by the client, allowing for very small packets to be sent between the UI and the client.
- play_
animation - UI message for informing the UI of an animation
- skybox_
update - UI message for updating the skybox
- ui_
messages - Structs for defining UI send and receive message types
- water_
update - UI message for rendering water