Errors created from messages and the session that should be from the core to the UI.
Structs
- AckError
- This represents errors that can arise from Acks failing. Acks are sent to and from the server to verify packages got to their destination. https://wiki.secondlife.com/wiki/PacketAck
- Capability
Error - Thrown when capabilities fail to get set
- Circuit
Code Error - This represents the errors that can arise from CircuitCodes failing. The CircuitCode is what the server returns after a successful login. https://wiki.secondlife.com/wiki/UseCircuitCode
- Complete
Agent Movement Error - This represents errors that can arise from a CompleteAgentMovment event failing. The CompleteAgentMovement packet is sent to finalize login. https://wiki.secondlife.com/wiki/CompleteAgentMovement
- Mailbox
Session Error - This represents errors that can arise from the mailbox failing to connect. The mailbox is part of the client that handles packet IO and other logic to pass to the UI.
Enums
- Feature
Error - this is for returning SessionErrors that result from optoinal features
- Session
Error - Represents errors that arise from failures within the core. These are sent as packets to the UI to inform the UI of errors within the core.