pub struct MailboxSessionError {
pub message: String,
}Expand description
This represents errors that can arise from the mailbox failing to connect. The mailbox is part of the client that handles packet IO and other logic to pass to the UI.
Fields
message: StringString message that contains error information